* Output options: all can be turned on/off by adding/ removing the NO;
  OPTIONS NOnumber NOdate NOcenter FormDlim=' ' PageSize=MAX LineSize=MAX NOfmterr;
* Remove default title, turn on new HTML graphics;
  TITLE; ODS GRAPHICS ON;

********************************************************************************;
*******    FIRST DEFINE "FILESAVE" PLACEHOLDER FOR FOLDER LOCATION       *******;
********************************************************************************;

* Paste in the folder address where "GSS_Example.xlsx" is saved after = before ;
%LET filesave= C:\Dropbox\21SP_PSQF6242\PSQF6242_Example3;
* Using UIowa virtual desktop instead;
*%LET filesave= \\Client\C:\Dropbox\20FA_PSQF6242\PSQF6242_Example3;

* IMPORT GSS_Example.xlsx data using filesave reference and exact file name;
* from the Excel workbook in DATAFILE= location from SHEET= ;
* New SAS file is in "work" library place with name "Example3";
* "GETNAMES" reads in the first row as variable names;
* DBMS=XLSX (can also use EXCEL or XLS for .xls files);
PROC IMPORT DATAFILE="&filesave.\GSS_Example.xlsx" 
            OUT=work.Example3 DBMS=XLSX REPLACE; 
     SHEET="GSS_Example"; 
     GETNAMES=YES; 
RUN;

* Create formats: set of value labels for categorical variables;
PROC FORMAT;
     VALUE Fmarry 1="1.Unmarried" 2="2.Married";
RUN;

* DATA = create new dataset, SET = from OLD dataset;
* So DATA + SET means "save as itself" after these actions;
* All data transformations must happen inside a DATA+SET+RUN combo;
DATA work.Example3; SET work.Example3;
* Label variables and apply value formats for variables used below;
* LABEL name=    "name: Descriptive Variable Label";
  LABEL marry=   "marry: 2-Category Marital Status"
        educ=    "educ: Years of Education"
        income=  "income: Annual Income in 1000s";
* Apply value labels created above: name Format.;
  FORMAT marry Fmarry.; 
* Select cases complete on variables of interest;
  IF NMISS(income,educ,marry)>0 THEN DELETE;
RUN;
* Now dataset work.Example3 is ready to use; 

* Sorting to find specific case for slides;
PROC SORT DATA=work.Example3; BY educ income; RUN;

* Open output directory to save results to;
ODS RTF FILE="&filesave.\Example3_SAS_Output.rtf" 
        STYLE=HTMLBlue STARTPAGE=NO BODYTITLE;

******************************************************************************;
*******      BEGIN EXAMPLES OF DATA DESCRIPTION FOR EXAMPLE 3          *******;
******************************************************************************;

TITLE "SAS Descriptive Statistics for Quantitative Variables";
PROC MEANS NDEC=3 NOLABELS N MEAN STDDEV VAR MIN MAX DATA=work.Example3; 
     VAR income educ;
RUN; TITLE;

* Histograms to visualize quantitative variables;
* NOPRINT spares the rest of the results I do not want right now;
TITLE "SAS Histograms of Quantitative Variables";
PROC UNIVARIATE NOPRINT DATA=work.Example3;
     VAR income educ; 
     HISTOGRAM income / MIDPOINTS=0 TO 70 BY 5; 
     HISTOGRAM educ   / MIDPOINTS=0 TO 20 BY 1; 
RUN; QUIT; TITLE;

TITLE "SAS Descriptive Statistics for Categorical Variable";
PROC FREQ DATA=work.Example3; 
     TABLE marry;
RUN; TITLE;

TITLE "SAS Pearson Correlations and CIs";
PROC CORR NOSIMPLE DATA=work.Example3 FISHER(BIASADJ=NO ALPHA=.05);
     VAR income educ marry;
RUN; TITLE;

******************************************************************************;
*******    BEGIN EXAMPLES OF GENERAL LINEAR MODELS FOR EXAMPLE 3       *******;
******************************************************************************;

TITLE "SAS GLM Empty Model Predicting Income";
PROC GLM DATA=work.Example3 NAMELEN=100;
     MODEL income = / SOLUTION ALPHA=.05 CLPARM;
RUN; QUIT; TITLE;

TITLE "SAS GLM Predicting Income from Original Education";
PROC GLM DATA=work.Example3 NAMELEN=100; *PLOTS(UNPACK)=DIAGNOSTICS;
     MODEL income = educ / SOLUTION ALPHA=.05 CLPARM;
RUN; QUIT; TITLE;

TITLE "SAS Scatterplot with a regression line to show the regression slope";
PROC SGPLOT DATA=work.Example3;
     SCATTER x=educ y=income;
     REG     x=educ y=income;
     XAXIS LABEL="Years of Education" VALUES=(0 TO 20 BY 2);
     YAXIS LABEL="1000s of Income" VALUES=(-20 TO 70 BY 10);
RUN;

* Center education predictor so that 0 is meaningful;
DATA work.Example3; SET work.Example3;
     educ12=educ-12; 
     LABEL educ12= "educ12: Education (0=12 years)";
RUN;

TITLE "SAS GLM Predicting Income from Centered Education (0=12)";
PROC GLM DATA=work.Example3 NAMELEN=100 PLOTS(UNPACK)=DIAGNOSTICS;
     MODEL income = educ12 / SOLUTION ALPHA=.05 CLPARM;
* In ESTIMATEs below, words refer to the estimated beta fixed effect,
  and values are the multiplier for the requested predictor value;
     ESTIMATE "Pred Income  8 years (educ12=-4)" intercept 1 educ12 -4;
     ESTIMATE "Pred Income 12 years (educ12= 0)" intercept 1 educ12  0;
     ESTIMATE "Pred Income 16 years (educ12= 4)" intercept 1 educ12  4;
     ESTIMATE "Pred Income 20 years (educ12= 8)" intercept 1 educ12  8;
RUN; QUIT; TITLE;

TITLE "SAS Scatterplot with a regression line to show the regression";
PROC SGPLOT DATA=work.Example3;
     SCATTER x=educ12 y=income;
     REG     x=educ12 y=income;
     XAXIS LABEL="Education (0=12 Years)" VALUES=(-8 TO 8 BY 2);
     YAXIS LABEL="1000s of Income" VALUES=(-20 TO 70 BY 10);
* Prediction from empty model;
     REFLINE 17.30 / AXIS=Y LINEATTRS=(COLOR=PURPLE THICKNESS=1); 
RUN;

TITLE1 "SAS GLM Predicting Income from Centered Education";
TITLE2 "Using REG instead of GLM to get standardized Effects";
PROC REG DATA=work.Example3; 
     MODEL income = educ12 / STB; * STB option gives standardized solution;
RUN; QUIT; TITLE1; TITLE2;

* Center marry predictor so that 0 is meaningful;
DATA work.Example3; SET work.Example3;
     marry01=.; * Create new empty variable, then recode;
     IF marry=1 THEN marry01=0;
     IF marry=2 THEN marry01=1;
     LABEL marry01= "marry01: 0=unmarried, 1=married";
RUN;

TITLE "SAS GLM Predicting Income from Marry01 (0=Unmarried,1=Married)";
PROC GLM DATA=work.Example3 NAMELEN=100 PLOTS(UNPACK)=DIAGNOSTICS;
     MODEL income = marry01 / SOLUTION ALPHA=.05 CLPARM;
* ESTIMATEs below request predicted outcome means for each group; 
     ESTIMATE "Income for Unmarried (marry01=0)" intercept 1 marry01 0; * Beta0;
     ESTIMATE "Income for Married   (marry01=1)" intercept 1 marry01 1; * Beta0+Beta1;
RUN; QUIT; TITLE;

* Compute d effect size for marry01 from t test-statistic;
DATA work.MakeD; 
     d=2*6.25/SQRT(732);
RUN;
* Print results of d computation;
PROC PRINT NOOBS DATA=work.MakeD;
RUN;

* Close output;
ODS RTF CLOSE;
